## Publishing
`python -m build`

`python -m twine upload dist/*` (requires PyPi API token)

## Installation
The package is published to the PyPi package index and can be installed with standard pip commands.

`pip install auto-trainer-training`
